# Summary

- [Introduction](./introduction.md)

# API Reference

- [Overview](./api/overview.md)
- [Conventions](./api/conventions.md)
- [Thread Safety](./api/thread-safety.md)
- [Error Codes](./api/error-codes.md)
- [Backend Identifiers](./api/backend-identifiers.md)
- [Context Management](./api/context-management.md)
- [Backend Registry Functions](./api/registry-functions.md)
- [Backend Functions](./api/backend-functions.md)
- [Voice Parameters](./api/voice-parameters.md)
- [Voice Selection](./api/voice-selection.md)
- [Audio Format](./api/audio-format.md)
- [Utilities](./api/utilities.md)
- [Audio Callback](./api/audio-callback.md)
